@@ -48,26 +48,19 @@ Kwappen::Kwappen()
 
   bgroup = new QButtonGroup(NULL,NULL);
   rotatebutton1 = new QPushButton("1",this);
-  rotatebutton1->setGeometry(20,647,80,24);
   bgroup->insert(rotatebutton1);
   rotatebutton2 = new QPushButton("2",this);
-  rotatebutton2->setGeometry(130,647,80,24);
   bgroup->insert(rotatebutton2);
   rotatebutton3 = new QPushButton("3",this);
-  rotatebutton3->setGeometry(240,647,80,24);
   bgroup->insert(rotatebutton3);
   rotatebutton4 = new QPushButton("4",this);
-  rotatebutton4->setGeometry(350,647,80,24);
   bgroup->insert(rotatebutton4);
   connect(bgroup, SIGNAL(clicked(int)),SLOT(rotateColumns(int)));
-
   swapbutton = new QPushButton(i18n("Swap stone 1x"),this);         // swap button
-  swapbutton->setGeometry(450,647,180,24);
   connect(swapbutton, SIGNAL(clicked()),SLOT(swapComp()));
-
   timer = new QTimer(this);             // timer set
   connect(timer, SIGNAL(timeout()),SLOT(countSeconds()));
-  timer->start(1000,false);
+  timer->start(500,false);             // 500ms interval
 }
 
 int Kwappen::random_color()            // random color select for stones
@@ -118,6 +111,9 @@ void Kwappen::eatblank()               // eat spaces (string)
 void Kwappen::start_turm()
 {
   char reihe, spalte;
+  swap = 0;                                  // clear computer stone swapflag
+  swapbutton->setText(i18n("Swap stone 1x")); 
+  swapbutton->setEnabled(true);
   do                                         // loop avoids rows with same card color
   {
     for(spalte = 0; spalte <= 3; spalte++)   // clear columns
@@ -136,7 +132,7 @@ void Kwappen::start_turm()
   }while(found);
   stein1 = random_color();                   // computer arms
   sekunden = 0;                              // second counter to 0
-  timer->start(1000,false);                  // start timer (1000 ms interval)
+  timer->start(500,false);                   // start timer (500 ms interval)
 }
 
 void Kwappen::draw_turmset()                 // move selected stone
@@ -312,7 +308,6 @@ void Kwappen::ende_check()                       // end checking
     {
       if (turm[reihe][spalte] > 0)  j++;
       else break;
-
     }
     if (j > 9 )
     {
@@ -412,7 +407,7 @@ void Kwappen::paintEvent(QPaintEvent*)              // paint event
   p.drawImage(500, 80, picture, (stein1-1)*79, 129, 79, 59);  // draw computer stone
   p.setFont(QFont("courier", 24, QFont::Bold));
   p.setPen(Qt::darkBlue);
-  sprintf(zeitstr,"TIME:%5u",sekunden);                       // show time
+  sprintf(zeitstr,"TIME:%5u",sekunden/2);                     // show time
   eatblank();
   p.drawText(458,205,180,30, Qt::AlignLeft, zeitstr);
   p.setPen(Qt::black);
@@ -435,14 +430,12 @@ void Kwappen::paintEvent(QPaintEvent*)              // paint event
             p.setFont(QFont("courier", 12, QFont::Bold));
             p.drawText(455,155,200,30, Qt::AlignLeft, i18n("Select one stone"));
             p.drawText(455,175,200,30, Qt::AlignLeft, i18n("in the 4 columns"));
-            p.setPen(Qt::black);
             break;
     case 1: p.setPen(Qt::red);                             // select column for own stone
             p.setFont(QFont("courier", 12, QFont::Bold));
             p.drawText(455,155,200,30, Qt::AlignLeft, i18n("Select a column"));
             p.drawText(455,175,200,30, Qt::AlignLeft, i18n("for stone move"));
             p.drawImage(20+steiny*110, 579-steinx*59, picture, (turm[steinx][steiny] - 1)*79, 64, 79, 59);
-            p.setPen(Qt::black);
             break;
     case 2: draw_turmset();                         // set own stone on column top
             set_computer();                         // set computer stone on random column
@@ -488,19 +481,21 @@ void Kwappen::paintEvent(QPaintEvent*)              // paint event
             break;
    case 11: timer->stop();                 // stop timer
             sekunden--;
-            status = -1;
+            highE->sec = sekunden / 2;
             pos = highS->testHighscore();  // check highscore entry
             if (pos != -1)
             {
-              highE->show();
+              status = 12;
               highE->writeHighscore(pos);
+              highE->show();
             }
             else
             {
-              QMessageBox::information(0,"Kwappen",i18n("You win, yeah !")); }
-              start_turm();
-              break;
+               QMessageBox::information(0,"Kwappen",i18n("You win, yeah !"));
+               status = -1;
+               start_turm();
             }
+  }
   p.end();
   bitBlt(this, 0, 0, &buffer);              // copy graphic buffer to screen
 }
@@ -511,7 +506,7 @@ void Kwappen::mousePressEvent(QMouseEvent* e)          // mouse handling
   x = clickedPos.x();  y = clickedPos.y();
   steinx = 0; steiny = 0;
   if (x >= 20 && x <= 639 && y >= 10 && y <= 639)      // check stone position
-  { if ((x >= 20) && (x <= 100)) steiny = 0;
+  { if (x <= 100) steiny = 0;
     else if ((x >= 130) && (x <= 210)) steiny = 1;     // determine column no.
     else if ((x >= 240) && (x <= 320)) steiny = 2;
     else if ((x >= 350) && (x <= 430)) steiny = 3;
@@ -523,18 +518,10 @@ void Kwappen::mousePressEvent(QMouseEvent* e)          // mouse handling
     }
     if (status == 1)                                   // column marked
     {
-       if (e->button() == RightButton)                 // disable selected stone
-       {
-         status = 0;
-         repaint();
-         return;
-       }
-       else
-       {
-         status = 2;
-         repaint();
-         return;
-       }
+       if (e->button() == RightButton)  status = 0;    // disable selected stone
+       else status = 2;
+       repaint();
+       return;
     }
     steinx = (639 - y) / 59;
     if (turm[steinx][steiny] == 0)                     // no stone found
@@ -553,6 +540,11 @@ void Kwappen::mousePressEvent(QMouseEvent* e)          // mouse handling
 
 void Kwappen::resizeEvent(QResizeEvent* event)        // resize event
 {
+  rotatebutton1->setGeometry(20,647,80,24);
+  rotatebutton2->setGeometry(130,647,80,24);
+  rotatebutton3->setGeometry(240,647,80,24);
+  rotatebutton4->setGeometry(350,647,80,24);
+  swapbutton->setGeometry(450,647,180,24);
   buffer.resize(event->size());
 }
 
@@ -759,7 +751,7 @@ char Highscore::testHighscore()    // test new highscore entry
 {
   int zeit;
   char i;
-  zeit = topW->sekunden;
+  zeit = topW->sekunden/2;
   loadHighscore();
   for (i = 0; i <= 49; i++)
   {
@@ -779,7 +771,7 @@ void HighscoreEdit::writeHighscore(char pos)  // write highscore file
   FILE* stream;
   char tempstr[50];
   char playn[50][50];
-  zeit = topW->sekunden;
+  zeit = topW->sekunden/2;
   stream = fopen(home_path+"kwappen/kwappen_highscore.txt", "rt");
   if (! stream)  return;
   for(i = 0; i < 50; i++)          // read player names from file
@@ -842,7 +834,7 @@ void HighscoreEdit::paintEvent(QPaintEvent*)      // highscore paint event
   p.setBackgroundColor(Qt::white);
   p.setBrush(Qt::lightGray);
   p.drawRect(0,0,270,300);
-  sprintf(tempstr,"%5u\n",topW->sekunden);
+  sprintf(tempstr,"%5d\n", sec);
   strcpy(tempstr1,"Highscore = ");
   sprintf(rankstr,"Highscore position: %2u\n",rank);
   p.drawText(10,20,260,30, Qt::AlignLeft, rankstr);
@@ -858,6 +850,9 @@ void HighscoreEdit::getHighscore()   // input name highscore of player
 {
   strcpy(playerName, highscoreentry->text());
   highE->hide();
+  topW->status = -1;
+  topW->start_turm();
+  topW->repaint();
 }
 
 HighscoreEdit::HighscoreEdit(QWidget* parent, const char* name, WFlags f) : QDialog(parent, name, TRUE, f)
